##  Exporting and Sharing Reports
Export and Share: Once you have customized your report, you can export it in various formats, such as PDF, PNG Image, or HTML Embed Code, and share it with stakeholders. With the HTML Embed Code, you can embed and have live data from the SAP LeanIX inside a tool such as Confluence and PowerPoint (using a Web Viewer add-ins). Admins and members can export reports. However, it depends on whether they have export permission for the fact sheet types included in the report. For more details, see [Report Permissions](https://help.sap.com/docs/leanix/ea/using-reports?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a74687a441014a0988e439b9077b4__report_permissions).
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2752a0e47a4410148fcca5d8c350775a_LowRes.png)
